@@ -728,8 +728,10 @@ class Builder(Update):
         chroot_path = self.clVars.Get('cl_builder_path')
         logfile = self._get_log_file()
         with EmergeParser(self.chrootize(chroot_path, EmergeCommand(
-                (["--depclean", "--with-bdeps=n", "--ask=y"]
-                 if without_bdeps else ["--depclean", "--ask=y"]),
+                (["--depclean", "--dynamic-deps=n", 
+                  "--with-bdeps=n", "--ask=y"]
+                 if without_bdeps else ["--depclean", "--dynamic-deps=n",
+                                        "--ask=y"]),
                 logfile=logfile,
                 emerge_default_opts=deo))) as emerge:
             try:
